@@ -108,6 +108,7 @@ giop_connection_get_property (GObject           *object,
 	}
 }
 
+
 static void
 giop_connection_class_init (GIOPConnectionClass *klass)
 {
@@ -153,7 +154,7 @@ giop_connection_get_type (void)
 			NULL,           /* class_data */
 			sizeof (GIOPConnection),
 			0,              /* n_preallocs */
-			(GInstanceInitFunc) giop_connection_init,
+			(GInstanceInitFunc) giop_connection_init
 		};
       
 		object_type = g_type_register_static (
@@ -186,40 +187,15 @@ giop_connection_initiate (gpointer orb_data,
 			 NULL);
 }
 
-void
+LinkConnectionStatus
 giop_connection_try_reconnect (GIOPConnection *cnx)
 {
-	link_connection_try_reconnect (LINK_CONNECTION (cnx));
+	return link_connection_try_reconnect (LINK_CONNECTION (cnx));
 }
 
 void
-giop_connections_shutdown (void)
+giop_set_timeout (guint msec)
 {
-#warning FIXME: Need to shutdown linc connections ...
-#ifdef G_ENABLE_DEBUG
-	g_warning ("FIXME: Need to shutdown linc connections ...");
-#endif
-#if 0
-	GList *l, *to_close;
-
-	CNX_LIST_LOCK;
-
-	to_close = cnx_list.list;
-	cnx_list.list = NULL;
-
-	CNX_LIST_UNLOCK;
-
-	for (l = to_close; l; l = l->next) {
-		GIOPConnection *cnx = l->data;
-
-		giop_connection_close (cnx);
-		giop_connection_unref (cnx);
-	}
-
-	g_list_free (to_close);
-
-	if (cnx_list.list != NULL)
-		g_warning ("Wierd; new connections opened while shutting down");
-#endif
-}
+	link_set_timeout (msec);
+} 
 
